@@ -9,7 +9,7 @@
 #define _F_LEADING_ONES_H
 
 
-#include "IOHprofiler_problem.hpp"
+#include "IOHprofiler_problem.h"
 
 class LeadingOnes : public IOHprofiler_problem<int> {
 public:
@@ -21,18 +21,13 @@ public:
     IOHprofiler_set_lowerbound(0);
     IOHprofiler_set_upperbound(1);
     IOHprofiler_set_best_variables(1);
-    Initilize_problem(dimension);
-  }
-  
-  ~LeadingOnes() {};
-
-  void Initilize_problem(int dimension) {
     IOHprofiler_set_number_of_variables(dimension);
     IOHprofiler_set_optimal((double)dimension);
-  };
+  }
+  
+  ~LeadingOnes() {}
 
   double internal_evaluate(const std::vector<int> &x) {
-    
     int n = x.size();
     int result = 0;
     for (int i = 0; i != n; ++i) {
@@ -42,11 +37,11 @@ public:
         break;
     }
     return (double)result;
-  };
+  }
   
   static LeadingOnes * createInstance(int instance_id = DEFAULT_INSTANCE, int dimension = DEFAULT_DIMENSION) {
     return new LeadingOnes(instance_id, dimension);
-  };
+  }
 };
 
 #endif
