@@ -8,7 +8,7 @@
 #ifndef _F_LEADING_ONES_RUGGEDNESSTWO_H
 #define _F_LEADING_ONES_RUGGEDNESSTWO_H
 
-#include "IOHprofiler_problem.hpp"
+#include "IOHprofiler_problem.h"
 #include "wmodels.hpp"
 
 class LeadingOnes_Ruggedness2 : public IOHprofiler_problem<int> {
@@ -22,14 +22,10 @@ public:
     IOHprofiler_set_lowerbound(0);
     IOHprofiler_set_upperbound(1);
     IOHprofiler_set_best_variables(1);
-    Initilize_problem(dimension);
+    IOHprofiler_set_number_of_variables(dimension);
   }
   
-  ~LeadingOnes_Ruggedness2() {};
-  
-  void Initilize_problem(int dimension) {
-    IOHprofiler_set_number_of_variables(dimension);
-  };
+  ~LeadingOnes_Ruggedness2() {}
 
   double internal_evaluate(const std::vector<int> &x) {
 
@@ -44,11 +40,11 @@ public:
     }
     result = ruggedness2(result,n);
     return (double)result;
-  };
+  }
 
   static LeadingOnes_Ruggedness2 * createInstance(int instance_id = DEFAULT_INSTANCE, int dimension = DEFAULT_DIMENSION) {
     return new LeadingOnes_Ruggedness2(instance_id, dimension);
-  };
+  }
 };
 
 #endif
