@@ -8,7 +8,7 @@
 #ifndef _F_LINEAR_H
 #define _F_LINEAR_H
 
-#include "IOHprofiler_problem.hpp"
+#include "IOHprofiler_problem.h"
 
 class Linear : public IOHprofiler_problem<int> {
 public:
@@ -24,24 +24,24 @@ public:
     Initilize_problem(dimension);
   }
   
-  ~Linear() {};
+  ~Linear() {}
 
   void Initilize_problem(int dimension) {
     IOHprofiler_set_number_of_variables(dimension);
-  };
+  }
 
   double internal_evaluate(const std::vector<int> &x) {
     int n = x.size();
     double result = 0;
     for (int i = 0; i < n; ++i) {
-      result += (double)x[i] * (double)(i+1);
+      result += (double)x[i] * (double)(i + 1);
     }
     return (double)result;
-  };
+  }
 
   static Linear * createInstance(int instance_id = DEFAULT_INSTANCE, int dimension = DEFAULT_DIMENSION) {
     return new Linear(instance_id, dimension);
-  };
+  }
 };
 
 #endif
