@@ -9,7 +9,7 @@
 #ifndef _F_ONE_MAX_DUMMYONE_H
 #define _F_ONE_MAX_DUMMYONE_H
 
-#include "IOHprofiler_problem.hpp"
+#include "IOHprofiler_problem.h"
 #include "wmodels.hpp"
 
 class OneMax_Dummy1 : public IOHprofiler_problem<int> {
@@ -22,16 +22,12 @@ public:
     IOHprofiler_set_lowerbound(0);
     IOHprofiler_set_upperbound(1);
     IOHprofiler_set_best_variables(1);
-    Initilize_problem(dimension);
+    IOHprofiler_set_number_of_variables(dimension);
+    IOHprofiler_set_optimal(floor((double)(dimension * 0.5)));
   }
 
   ~OneMax_Dummy1() {};
 
-  void Initilize_problem(int dimension) {
-    IOHprofiler_set_number_of_variables(dimension);
-    IOHprofiler_set_optimal(floor((double)(dimension * 0.5)));
-  };
-
   std::vector<int> info;
   void prepare_problem() {
     info = dummy(IOHprofiler_get_number_of_variables(),0.5,10000);
@@ -44,11 +40,11 @@ public:
       result += x[this->info[i]];
     }
     return (double)result;
-  };
+  }
   
   static OneMax_Dummy1 * createInstance(int instance_id = DEFAULT_INSTANCE, int dimension = DEFAULT_DIMENSION) {
     return new OneMax_Dummy1(instance_id, dimension);
-  };
+  }
 };
 
 #endif
